"""user module

 ver 1.5 for CG and FX model
 by Krtyski/e-Gadget

 Functions:
 ---------
 isCG()
 grp_color()
 circle()
 line()
 locate()
 frac()
"""
from math import *
from casioplot import *

def isCG():
 """Chcek calculator model

 version 1.0 for CG and FX model
 """
 if get_pixel(128,64)==None:
  return 0
 else:
  return 1

def grp_color(color=1):
 """Convert color parameter to rgb in tuple

 version 1.0
 """
 #set rgb from argument(color)
 rgb=[(255,255,255),(0,0,0),(0,0,255),(255,0,0),(255,0,255),(0,255,0),(0,255,255),(255,255,0)]
 c_name=['white','black','blue','red','magenta','green','cyan','yellow']

 if type(color) is int:
  if 0<=color<=7:
   c_rgb=rgb[color]
  else:
   c_rgb=(0,0,0)
 elif type(color) is str:
  if color in c_name:
   c_rgb=rgb[c_name.index(color)]
  else:
   c_rgb=(0,0,0)
 elif type(color) is tuple:
  c_rgb=color
 else: #fail-proof
  c_rgb=(0,0,0)
 
 return c_rgb


def circle(x,y,r,color=1,show=1):
 """Draw circle around (x,y) with radius r

 version 1.1 for CG and FX model
 """
 if isCG():
   px_max=383
   py_max=191
 else:
   px_max=127
   py_max=63
 rgb=grp_color(color)
 p=r*6.283 #number of plots
 a=2*pi/p #angle step in radian
 for i in range(p):
  px=x+r*cos(i*a)
  if px<0 or px>px_max:
   continue
  py=y+r*sin(i*a)
  if py<0 or py>py_max:
   continue
  set_pixel(int(px),int(py),rgb)
  if show: #data transfer to screen
   show_screen()


def line(x1,y1,x2,y2,color=1,show=1):
 """Draw line from (x1,y1) to (x2,y2)
 
 version 1.2
 """
 rgb=grp_color(color)
 dx=x2-x1;dy=y2-y1
 if dx==0 and dy==0: #avoid division by 0 error
   set_pixel(x1,y1,rgb)
   return
 if abs(dx)>abs(dy):
  if dx: #when dx is not 0
   k=int(dx/abs(dx)) #k=1 or -1
   slope=dy/dx
   for x in range(0,dx,k):
    set_pixel(x1+x,y1+int(x*slope),rgb)
 else:
  if dy: #when dy is not 0
   k=int(dy/abs(dy)) #k=1 or -1
   slope=dx/dy
   for y in range(0,dy,k):
    set_pixel(x1+int(y*slope),y1+y,rgb)

 if show:
  show_screen()


def locate(column,row,obj,color=1,size='m',show=1):
 """Locate number or string on graphic screen
 
 version 1.1 for CG and FX model
 """
 #set fontsize & pitch
  if isCG(): #CG model
   dx={'s':8,'m':12,'l':16}
   dy={'s':12,'m':16,'l':24}
 else: #FX model
   dx={'s':4,'m':4,'l':6}
   dy={'s':6,'m':6,'l':8}
 #from 5th argument(size)
 sz={'s':'small','m':'medium','l':'large'}

 #data transfer to VRAM
 draw_string(column*dx[size],row*dy[size],str(obj),grp_color(color),sz[size])
 
 if show: #data transfer to screen
  show_screen() 


def frac(x):
 """Get decimal part
 
 version 1.0
 """
 return x-int(x)
   